flare.tiger(data, lambda = NULL, nlambda = NULL, lambda.min.ratio = NULL,
rho = NULL, method = "slasso", alg = NULL, sym = "or",
shrink=NULL, prec = 1e-3, max.ite = NULL, wmat = NULL,
standardize = FALSE, correlation = FALSE, perturb = TRUE,
verbose = TRUE)"clime": (1) data is an n by d data matrix (2) a d by d sample covariance matrix. The program automatically identifies the input matrix by checking the slambda = NULL and have the program compute its own lambda sequence based on nlambda and lambda.min.ratlambda. Default value is 5.lambda, as a fraction of the uppperbound (MAX) of the regularization parameter. The program can automatically generate lambda as a sequence of length = nlambda starting from clime. The default value is $\sqrt{d}$.method = "slasso", CLIME is applied if method="clime", and adaptive CLIME is applied if method = "aclime". Default value is "slasso".method = "clime". The coordinate descent is applied if "alg = cdadm", and the linearization is applied if "alg = ladm". The combination of coordinate descensym = "and", the edge between node i and node j is selected ONLY when both node i and node j are selected as neighbors for each other. If sym = "or"method = "clime" and the default value is 0 if method="slasso" or method = "aclime".method = "clime" and alg = "ladm", and is 1e2 if method = "clime" and alg = "cdadm", or method = "slasso".method = "aclime".standardize = TRUE. The default value is FALSE.Sigma for method = "clime" if correlation = TRUE. The default value is FALSE.Sigma is added by a positive value to guarantee that Sigma is positive definite if perturb = TRUE. User can specify a numeric value for perturbe. The default value is TRUE.verbose = FALSE. The default value is TRUE."tiger" is returned:n by d data matrix or d by d sample covariance matrix from the input.lambda used in the program.lambda.d by d precision matrices corresponding to regularization parameters.sym from the input.method from the input.d by d adjacency matrices of estimated graphs as a graph path corresponding to lambda.method = "clime", it is a list of two matrices where ite[[1]] is the number of external iterations and ite[[2]] is the number of internal iterations with the entry of (i,j) as the number of iteration of i-th column and j-th lambda. If method="slasso", it is a matrix of iteration with the entry of (i,j) as the number of iteration of i-th column and j-th lambda.d by nlambda matrix. Each row contains the number of nonzero coefficients along the lasso solution path.standardize from the input.correlation from the input.perturb from the input.verbose from the input.Adaptive CLIME solves the following minimization problem
$$\min || W \circ \Omega ||_1 \quad \textrm{s.t. } | S \Omega - I | \le \lambda W,$$
where $\circ$ denotes the Hadamard product, and $A_{d \times d} \leq B_{d \times d}$ denotes the set of entrywise inequalities $a_{jk} TIGER solves the following minimization problem
$$\min ||X-XB||_{2,1} + \lambda ||B||_1 \quad \textrm{s.t. } B_{jj} = 0,$$
where $||\cdot||_{1}$ and $||\cdot||_{2,1}$ are element-wise 1-norm and $L_{2,1}$-norm respectively.
flare-package, flare.tiger.generator, flare.tiger.select, flare.plot, flare.tiger.roc, plot.tiger, plot.select, plot.roc, plot.sim, print.tiger, print.select, print.roc and print.sim.## generating data
n = 100
d = 100
D = flare.tiger.generator(n=n,d=d,graph="hub",g=10)
plot(D)
## sparse precision matrix estimation with method "clime"
out1 = flare.tiger(D$data, method = "clime")
plot(out1)
flare.plot(out1$path[[4]])
## sparse precision matrix estimation with method "slasso"
out2 = flare.tiger(D$data, method = "slasso")
plot(out2)
flare.plot(out2$path[[4]])
## sparse precision matrix estimation with method "aclime"
out3 = flare.tiger(D$data, lambda=seq(0.25, 0.1, length.out=5),
method = "aclime", wmat=1/(abs(D$omega)+1/n))
plot(out3)
flare.plot(out3$path[[5]])Run the code above in your browser using DataLab